/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: inetsocket_l.h 1393 2007-11-22 18:26:05Z martin $
    begin       : Tue Oct 02 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWEN_SOCKET_L_H
#define GWEN_SOCKET_L_H

#include <gwenhywfar/inetsocket.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Initializes this module.
 */
int GWEN_Socket_ModuleInit();

/**
 * Deinitializes this module.
 */
int GWEN_Socket_ModuleFini();


#ifdef __cplusplus
}
#endif

#endif /* #ifndef GWEN_SOCKET_H */


